@@ -30,8 +30,9 @@
 #include "asterisk/sdp_srtp.h"
 /* Needed for ast_media_type */
 #include "asterisk/codec.h"
-/* Needed for ast_sip_security_mechanism_vector */
-#include "asterisk/res_pjsip.h"
+/* Needed for pjmedia_sdp_session and pjsip_inv_session */
+#include <pjsip_ua.h>
+
 
 /* Forward declarations */
 struct ast_sip_endpoint;
@@ -61,6 +62,7 @@ enum ast_sip_session_t38state {
 
 struct ast_sip_session_sdp_handler;
 struct ast_sip_session;
+struct ast_sip_session_caps;
 struct ast_sip_session_media;
 
 typedef struct ast_frame *(*ast_sip_session_media_read_cb)(struct ast_sip_session *session, struct ast_sip_session_media *session_media);
@@ -91,14 +93,14 @@ struct ast_sip_session_media {
 	int timeout_sched_id;
 	/*! \brief Stream is on hold by remote side */
 	unsigned int remotely_held:1;
+	/*! \brief Stream is held by remote side changed during this negotiation*/
+	unsigned int remotely_held_changed:1;
 	/*! \brief Stream is on hold by local side */
 	unsigned int locally_held:1;
 	/*! \brief Does remote support rtcp_mux */
 	unsigned int remote_rtcp_mux:1;
 	/*! \brief Does remote support ice */
 	unsigned int remote_ice:1;
-	/*! \brief Stream is held by remote side changed during this negotiation*/
-	unsigned int remotely_held_changed:1;
 	/*! \brief Media type of this session media */
 	enum ast_media_type type;
 	/*! \brief The write callback when writing frames */
@@ -160,6 +162,12 @@ struct ast_sip_session_delayed_request;
 /*! \brief Opaque struct controlling the suspension of the session's serializer. */
 struct ast_sip_session_suspender;
 
+/*! \brief Indicates the call direction respective to Asterisk */
+enum ast_sip_session_call_direction {
+	AST_SIP_SESSION_INCOMING_CALL = 0,
+	AST_SIP_SESSION_OUTGOING_CALL,
+};
+
 /*!
  * \brief A structure describing a SIP session
  *
@@ -229,8 +237,8 @@ struct ast_sip_session {
 	AST_VECTOR(, struct ast_rtp_instance_stats *) media_stats;
 	/*! Number of challenges received during outgoing requests to determine if we are in a loop */
 	unsigned int authentication_challenge_count:4;
-	/*! Originating Line Info (ANI II digits) */
-	int ani2;
+	/*! The direction of the call respective to Asterisk */
+	enum ast_sip_session_call_direction call_direction;
 };
 
 typedef int (*ast_sip_session_request_creation_cb)(struct ast_sip_session *session, pjsip_tx_data *tdata);
@@ -274,6 +282,8 @@ enum ast_sip_session_response_priority {
  * processing to incoming and outgoing SIP requests and responses
  */
 struct ast_sip_session_supplement {
+	/*! Reference module info */
+	struct ast_module *module;
 	/*! Method on which to call the callbacks. If NULL, call on all methods */
 	const char *method;
 	/*! Priority for this supplement. Lower numbers are visited before higher numbers */
@@ -481,7 +491,7 @@ struct ast_sip_channel_pvt *ast_sip_channel_pvt_alloc(void *pvt, struct ast_sip_
  *
  * \param endpoint The endpoint that this session communicates with
  * \param contact The contact associated with this session
- * \param inv The PJSIP INVITE session data
+ * \param inv_session The PJSIP INVITE session data
  * \param rdata INVITE request received (NULL if for outgoing allocation)
  */
 struct ast_sip_session *ast_sip_session_alloc(struct ast_sip_endpoint *endpoint,
@@ -494,6 +504,8 @@ struct ast_sip_session *ast_sip_session_alloc(struct ast_sip_endpoint *endpoint,
  * \param session Which session to suspend the serializer.
  *
  * \note No channel locks can be held while calling without risk of deadlock.
+ *
+ * \return Nothing
  */
 void ast_sip_session_suspend(struct ast_sip_session *session);
 
@@ -502,6 +514,8 @@ void ast_sip_session_suspend(struct ast_sip_session *session);
  * \since 12.7.0
  *
  * \param session Which session to unsuspend the serializer.
+ *
+ * \return Nothing
  */
 void ast_sip_session_unsuspend(struct ast_sip_session *session);
 
@@ -718,6 +732,7 @@ int ast_sip_session_refresh(struct ast_sip_session *session,
  *
  * \param session The session on which the answer will be updated
  * \param on_sdp_creation Callback called when SDP is created
+ * \param generate_new_sdp Boolean to indicate if a new SDP should be created
  * \retval 0 Successfully updated the SDP answer
  * \retval -1 Failure to updated the SDP answer
  */
@@ -842,7 +857,6 @@ struct ast_sip_session_media *ast_sip_session_media_state_add(struct ast_sip_ses
 /*!
  * \brief Save a media stats.
  *
- * \param sip_session Session on which to save active media state for
  * \param media_state The media state to save
  */
 void ast_sip_session_media_stats_save(struct ast_sip_session *sip_session, struct ast_sip_session_media_state *media_state);
@@ -920,6 +934,7 @@ struct ast_sip_session_media *ast_sip_session_media_get_transport(struct ast_sip
 
 /*!
  * \brief Get the channel or endpoint name associated with the session
+ * \since 18.0.0
  *
  * \param session
  * \retval Channel name or endpoint name or "unknown"
